<p align="center">
  <img width="420px" src="https://raw.githubusercontent.com/suzukey/fitrate/main/docs/img/fitrate.png" alt='fitrate'>
</p>

<p align="center">
  <em>Calculate the length of the sides that fit into the limited volume</em>
</p>

<p align="center">
  <a href="https://pypi.org/project/fitrate/" target="_blank">
    <img src="https://img.shields.io/pypi/v/fitrate?color=blue" alt="Package version">
  </a>
</p>

---

**Documentation**:

**Demo**:

---

# fitrate

## Requirements

Python 3.6+

## Installation

```shell
$ pip3 install fitrate
```

## Example

```python
from fitrate import calc

print(calc((400, 300), 60000))
```

<p align="center">&mdash; 🎞️ &mdash;</p>

<p align="center">
  <i>fitrate is licensed under the terms of the <a href="https://github.com/suzukey/fitrate/blob/main/LICENSE">MIT license</a>.</i>
</p>
